@@ -1,5 +1,4 @@
 import numpy as np
-from typing import Callable
 
 # Referenced colorconv.py from scikit-image for more efficient implementation
 # of colorspace transformations. Will continue to maintain an independent
@@ -29,12 +28,12 @@ yuv_to_rgb = np.linalg.inv(rgb_to_yuv)
 
 # Used to normalize an image in a colorspace to [0,1]
 norm = \
-    {'RGB': {'scale': (255.0, 255.0, 255.0),
+    {'RGB': {'scale': (1.0, 1.0, 1.0),
              'shift': (0.0, 0.0, 0.0)},
-     'Lab': {'scale': (255.0, 255.0, 255.0),
-             'shift': (0.0, -128.0, -128.0)},
-     'YUV': {'scale': (1.0, 0.872, 1.23),
-             'shift': (0.0, -0.436, -0.615)}}
+     'Lab': {'scale': (1.0, 1.0, 1.0),
+             'shift': (0.0, -0.5, -0.5)},
+     'YUV': {'scale': (1.0, 1.0, 1.0),
+             'shift': (0.0, -0.5, -0.5)}}
 
 
 def RGB_to_gray(image: np.ndarray) -> np.ndarray:
@@ -106,7 +105,7 @@ def RGB_to_YUV(image: np.ndarray) -> np.ndarray:
     Returns:
         np.ndarray: Image in YUV space.
     """
-    return normalize(image, 'RGB') @ rgb_to_yuv.T
+    return image @ rgb_to_yuv.T
 
 
 def YUV_to_RGB(image: np.ndarray) -> np.ndarray:
@@ -121,7 +120,7 @@ def YUV_to_RGB(image: np.ndarray) -> np.ndarray:
     Returns:
         np.ndarray: Image in CIE RGB space.
     """
-    return denormalize(image @ yuv_to_rgb.T, 'RGB')
+    return image @ yuv_to_rgb.T
 
 
 def XYZ_to_Lab(image: np.ndarray, illuminant: str = 'D65') -> np.ndarray:
@@ -255,26 +254,3 @@ def denormalize(image: np.ndarray, color_space: str) -> np.ndarray:
     shift = norm[color_space]['shift']
     shift_mat = np.ones(image.shape) @ np.diag(shift)
     return (image @ np.diag(scale)) + shift_mat
-
-
-def apply_to_channels(image: np.ndarray,
-                      f_1: Callable,
-                      f_2: Callable,
-                      f_3: Callable) -> np.ndarray:
-    """Return the image with the functions applied to each channel.
-
-    Args:
-        image (np.ndarray): Image (recommended to be normalized).
-        f_1 (Callable): Function to apply to the first channel.
-        f_2 (Callable): Function to apply to the second channel.
-        f_3 (Callable): Function to apply to the third channel.
-
-    Returns:
-        np.ndarray: Pixel matrix with functions applied to each channel.
-    """
-    n,m,k = image.shape
-    p = np.reshape(image, (n*m,3)).astype(float)
-    p[:,0] = f_1(p[:,0])
-    p[:,1] = f_2(p[:,1])
-    p[:,2] = f_3(p[:,2])
-    return np.reshape(p, (n,m,k))
